@@ -7,4 +7,4 @@ Email: wenqiangw@opera.com
 Date: 2020-03-25 14:40
 Desc:
 '''
-from bert_extracter import ExtractBertFeatures,DownloadBertModel
\ No newline at end of file
+from .bert_extracter import ExtractBertFeatures,DownloadBertModel
\ No newline at end of file
