@@ -7,12 +7,16 @@ Email: wenqiangw@opera.com
 Date: 2020-03-25 14:40
 Desc:
 '''
+
 from bert4keras.models import build_transformer_model
 from bert4keras.tokenizers import Tokenizer
 import numpy as np
 import os
+import sys
 import requests
 import zipfile
+sys.path.append(os.path.abspath('../'))
+from util import progress_bar
 
 CUR_PASTH = os.path.dirname(os.path.abspath(__file__))
 
@@ -36,26 +40,37 @@ class ExtractBertFeatures:
 
 class DownloadBertModel:
     def __init__(self,url='https://storage.googleapis.com/bert_models/2020_02_20/uncased_L-2_H-128_A-2.zip'):
-        self.model_dir = url
-        name = url.split('/')[-1].split('.')[0]
-        self.save_parh = os.path.join(CUR_PASTH, 'data', name)
+        self.model_url = url
+        self.name = url.split('/')[-1].split('.')[0]
+        self.save_parh = os.path.join(CUR_PASTH, 'data', self.name)
 
-    def dump(self,save_parh=''):
+    def dump(self, save_parh=''):
         if not save_parh:
             save_parh = self.save_parh
         if not os.path.exists(save_parh):
             os.makedirs(save_parh)
-
-        r = requests.get(self.model_dir)
-        with open("_tmp.zip", "wb") as code:
-            code.write(r.content)
-
+        # 模型下载
+        url = self.model_url
+        with requests.get(url, stream=True) as r:
+            filesize = r.headers["Content-Length"]
+            chunk_size = 1024
+            times = int(filesize) // chunk_size
+            print("模型文件大小:", filesize, "bytes")
+            print("下载地址:", url)
+            print('-' * 30)
+            print("开始下载")
+            with open("_tmp.zip", "wb") as fw:
+                start = 0
+                for chunk in r.iter_content(chunk_size):
+                    fw.write(chunk)
+                    start += 1
+                    progress_bar(start, times)
+        # 解压文件
         f = zipfile.ZipFile('_tmp.zip', 'r')
         for file in f.namelist():
             f.extract(file,save_parh)
         os.remove("_tmp.zip")
 
-
 if __name__ == '__main__':
     aa=DownloadBertModel()
     aa.dump()
